@@ -1,18 +1,11 @@
 /*
- *
- * Copyright (C) 2003-2004 Christian Kvasny <chris@k3b.org>
- * Copyright (C) 2008 Sebastian Trueg <trueg@k3b.org>
- * Copyright (C) 2010 Michal Malek <michalm@jabster.pl>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2010 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 2003-2004 Christian Kvasny <chris@k3b.org>
+    SPDX-FileCopyrightText: 2008 Sebastian Trueg <trueg@k3b.org>
+    SPDX-FileCopyrightText: 2010 Michal Malek <michalm@jabster.pl>
+    SPDX-FileCopyrightText: 1998-2010 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3bvcdtrackdialog.h"
 #include "k3bglobals.h"
@@ -164,9 +157,9 @@ K3b::VcdTrackDialog::VcdTrackDialog( K3b::VcdDoc* doc, const QList<K3b::VcdTrack
         d->muxrate->setText( i18n( "%1 bit/s", selectedTrack->muxrate() ) );
 
         if ( selectedTrack->isSegment() )
-            d->labelMimeType->setPixmap( SmallIcon( "image-x-generic", KIconLoader::SizeMedium ) );
+            d->labelMimeType->setPixmap( QIcon::fromTheme("image-x-generic").pixmap(KIconLoader::SizeMedium) );
         else
-            d->labelMimeType->setPixmap( SmallIcon( "video-x-generic", KIconLoader::SizeMedium ) );
+            d->labelMimeType->setPixmap( QIcon::fromTheme("video-x-generic").pixmap(KIconLoader::SizeMedium) );
 
         fillGui();
     }
@@ -307,7 +300,7 @@ void K3b::VcdTrackDialog::fillPbcGui()
     }
 
     // add Event Disabled
-    QPixmap disabledIcon = SmallIcon( "process-stop" );
+    QPixmap disabledIcon = QIcon::fromTheme( "process-stop" ).pixmap( KIconLoader::SizeSmall );
     QString disabledName = i18n( "Event Disabled" );
     d->pbc_previous->addItem( disabledIcon, disabledName );
     d->pbc_next->addItem( disabledIcon, disabledName );
